@@ -16,18 +16,10 @@ def tabulate_reports(remote_calls, homecall_reports):
                 records.append((rc, hc, int(rp)))
 
     df = pd.DataFrame(records, columns=["remote", "home", "report"])
-
-    # pivot to table of max report
+    # pivot to table of max report for each home callsign
     pivot = df.groupby(["remote", "home"])["report"].max().unstack(fill_value=-30)
-
-    # include all expected rows/cols
     pivot = pivot.reindex(index=remote_calls, columns=homecall_reports.keys(), fill_value=-30)
 
-    # sort rows and cols by max report
- #   pivot = pivot.reindex(pivot.max(axis=1).sort_values(ascending=False).index)
- #   pivot = pivot[pivot.max(axis=0).sort_values(ascending=False).index]
-
-    # return same structure as before
     return pivot.index.tolist(), pivot.columns.tolist(), pivot.values.tolist()
 
 
@@ -88,10 +80,11 @@ def read_csv(filepath =  "decodes.csv", start_epoch = 0):
     with open(filepath, "r") as f:
         for l in f.readlines():
             ls=l.strip().split(", ")
-            d = {'t':ls[0], 'b':ls[1], 'f':ls[2], 'md':ls[3], 'hc':ls[4], 'hl':ls[5], 'ha':ls[6], 'TxRx':ls[7], 'oc':ls[8], 'ol':ls[9], 'oa':ls[10], 'rp':ls[11]}
-            if(int(d['t']) < start_epoch):
-                continue
-            decodes.append(d)
+            if(len(ls) == 12):
+                d = {'t':ls[0], 'b':ls[1], 'f':ls[2], 'md':ls[3], 'hc':ls[4], 'hl':ls[5], 'ha':ls[6], 'TxRx':ls[7], 'oc':ls[8], 'ol':ls[9], 'oa':ls[10], 'rp':ls[11]}
+                if(int(d['t']) < start_epoch):
+                    continue
+                decodes.append(d)
             
     print(f"Read {len(decodes)} decodes from {filepath}")
     return decodes
