@@ -87,19 +87,6 @@ def do_plots(timewin_start_offset_secs):
                 plt.savefig(f"plots/{RxTx}_{band}_{mode}.png")
                 plt.close()
 
-def do_periodic_uploads(uploadsecs):
-    with open("upload.bat", "w") as f:
-        print("Writing upload.bat")
-        f.write("git add -f ./plots/*.png\n")
-        f.write("git commit -m 'upload local data'\n")
-        f.write("git pull\n")
-        f.write("git clean -f\n")
-        f.write("git push -f\n")
-    while (True):
-        subprocess.Popen(["upload.bat"], creationflags=subprocess.CREATE_NO_WINDOW)
-        time.sleep(uploadsecs)
-
-
 def get_args_and_run():
     from importlib.metadata import version
     try:
@@ -133,10 +120,19 @@ def get_args_and_run():
         print("Starting Tx listener")
         subprocess.Popen(["hamplots", "start_tx", "--runsecs", "1000000"], creationflags=subprocess.CREATE_NO_WINDOW)
         uploadsecs = int(args.uploadsecs)
-        print(f"Starting Uploader with period {uploadsecs}")
-        subprocess.Popen(["hamplots", "start_uploader", "--uploadsecs", str(uploadsecs)], creationflags=subprocess.CREATE_NO_WINDOW)
-
-
+        plotsecs = int(args.plotsecs)
+        print(f"Starting Uploader with period {uploadsecs} secs and plot window {plotsecs} secs")
+        with open("upload.bat", "w") as f:
+            print("Writing upload.bat")
+            f.write("hamplots do_plots --plotsecs {plotsecs}")
+            f.write("git add -f ./plots/*.png\n")
+            f.write("git commit -m 'upload local data'\n")
+            f.write("git pull\n")
+            f.write("git clean -f\n")
+            f.write("git push -f\n")
+        while (True):
+            subprocess.Popen(["upload.bat"], creationflags=subprocess.CREATE_NO_WINDOW)
+            time.sleep(uploadsecs)
 
 
 
